/*
** Copyright (C) 12 Mar 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

typedef enum {
	false,
	true
} bool;

typedef struct {
	bool enable_tooltips;
	bool own_progresswin;
	bool dummy;
	bool eject;
	bool set_multisession;
	bool do_ms_check;
	bool get_size;
	bool beep;
	bool burnproof;
	bool disable_fixate;
	bool completion_msg;
	char *old_session;
} misc_preferences;

extern misc_preferences misc_prefs;

void apply_misc_changes(void);
void apply_storage_changes(void);
void preferences_cmd_callback(GtkWidget *, gpointer);

